import java.util.*;
import javax.microedition.lcdui.*;
import javax.microedition.midlet.*;
import com.nokia.mid.ui.*;
import javax.microedition.rms.*;

class AlarmTime {
  private int hour;
  private int minute;
  private boolean isEnabled;
  private String recordName;
  private RecordStore recordStore = null;
  
  public AlarmTime(String recordPostfix){
    hour = 8;
    minute = 30;
    isEnabled = true;
    recordName = "alarmTime"+recordPostfix;
    
    try {
      recordStore = RecordStore.openRecordStore(recordName, true);
      int rsSize = recordStore.getNumRecords();
      
      if (rsSize < 1) {
        // RecordStore is yet empty, create an inital entry
        this.save();
      } else {
        // RecordStore is not yet empty, load from first entry
        this.load();
      }
    }
    catch (RecordStoreException rse) {
      rse.printStackTrace();
    }  
  }

  public AlarmTime(int h, int m){
    set(h, m);
  }  

  public void set(int h, int m){
    hour = h;
    minute = m;
  }

  public void set(boolean bEnabled){
    isEnabled = bEnabled;
  }

  public int hour() {
    return this.hour;
  }

  public int minute() {
    return this.minute;
  }

  public boolean isEnabled(){
    return this.isEnabled;
  }
  
  public void load(){
    try {
      if (null != recordStore){
        int rsSize = recordStore.getNumRecords();
        if (rsSize > 0) {
          fromBytes(recordStore.getRecord(1));
        }
      }
    }
    catch (RecordStoreException rse) {
      rse.printStackTrace();
    }      
  }
  
  public void save(){
    try {
      if (null != recordStore){
        byte[] thisBytes = this.getBytes();
        int rsSize = recordStore.getNumRecords();
        if (rsSize < 1) {
          recordStore.addRecord(thisBytes, 0, thisBytes.length);
        } else {
          recordStore.setRecord(1, thisBytes, 0, thisBytes.length);
        }
      }
    }
    catch (RecordStoreException rse) {
      rse.printStackTrace();
    }      
  }  
  
  public String toString(){
    if(this.isEnabled){
      return "1"+ BombUtils.addLeadingZeros(this.hour, 2) + BombUtils.addLeadingZeros(this.minute, 2);
    } else {
      return "0"+ BombUtils.addLeadingZeros(this.hour, 2) + BombUtils.addLeadingZeros(this.minute, 2);
    }
  }
  
  public byte[] getBytes(){
    return toString().getBytes();
  }
  
  public void fromBytes(byte[] bytes){
    String thisString = new String(bytes); // should be something like "01234" (= 12:34, not enabled)
    String strHour = thisString.substring(1, 3);
    String strMinute = thisString.substring(3, 5);
    
    this.hour = Integer.parseInt(strHour);
    this.minute = Integer.parseInt(strMinute);
    
    if (thisString.charAt(0) == '1'){
      this.set(true);
    } else {
      this.set(false);
    }
  }

}
